
# Run all code to produce all graphs
# Principle: each function f is stored in a file of name f.r and can be 
# called as f() without arguments (or better: with default arguments)

# --- Initialization

cat("\n\nStarting batch run.\n\n")

if(!file.exists("graphs"))
	dir.create("graphs")

cat("Clearing out graphs directory (graphs).\n")
del <- list.files(path="graphs", full.names=TRUE)
cat("Removing ", length(del), " files.\n", sep="")
for(what in del) file.remove(what)

cat("\nClearing out working session.\n")
rm(list=ls())

setup <- list(
	dir.graphs="./graphs"	# location for storing graphics files
)

# Library of tools

cat("Tools definitions.\n")

source("graph2file.R")	# write a trellis/lattice object to file

# --- end Initialization

# ---
# Figure 1: bwplot of safety data (type of AE ~ frequency)

source("safety.barchart.R")
x <- safety.barchart()$as.is
graph2file(x, file="01-safety.barchart", w=c(800, 8), h=c(500, 5))

# ---
# Figure 2: exposure pre and post intervention

source("exposure.R")
x <- exposure()$graphs$combo
graph2file(x, file="02-exposure", w=c(640, 8), h=c(320, 3.5))

# ---
# Figure 3: axis range 
# Note: this function uses old-style graphics, so no trellis object is returned
# and we write the graph to file "manually".

source("axis.ranges.R")
f <- paste(setup$dir.graphs, "03-axis.ranges.%03d", sep="/")

png(paste(f, ".png", sep=""), w=720, h=360)
axis.ranges()
dev.off()

win.metafile(paste(f, ".wmf", sep=""), w=7, h=8/3)
axis.ranges()
dev.off()

rm(f)

# ---
# Figure 4: predicted versus observed
# Note: the graph is a layout of 3 graphs
# Note: graph width must be 2x graph height such that the rhs graph is square

source("obspred.R")
x <- obspred()$combo
graph2file(x, "04-obspred", w=c(640, 9), h=c(480, 5))

# ---
# Figure 5: safety bar charts (combination/layoutof different varieties)
# Note that this function has been called before for Fig 1
# Note: the function has to be quite wide such that the text does not
# occupy most of the figure.

source("safety.barchart.R")

x <- safety.barchart()$combo
graph2file(x, "05-safety.barchart", w=c(1200, 10), h=c(400, 4))

# ---
# Figure 6: PK profiles in different arrangements

source("pkprofiles.R")
x <- pkprofiles()$combo
graph2file(x$combo, "06-pkprofiles", width=c(800, 8), height=c(400, 4))

# ---
# Figure 7: Change from baseline xyplot figures

source("change.from.baseline.R")
x <- change.from.baseline()$combo
graph2file(x, "07-change.from.baseline", width=c(960, 8), height=c(480, 4))

# ---
# Figure 8: outliers

source("outliers.R")
x <- outliers()$combo
graph2file(x, "08-outliers", width=c(960, 8), height=c(480, 4))

# --- 
# Figure 9 is a 3D bar chart created from Excel. See the separate directory.

# --- 
# Figure 10 is a 3D bar/column chart created from Excel. 
# See the separate directory.

# ---
# Figure 11: FEV1 surface and slices.

source("FEV1.predicted.R")
source("FEV1.predicted.graph.R")

x <- FEV1.predicted.graph()$combo
graph2file(x, "11-FEV1", width=c(800, 8), height=c(500, 5))

# ---
# Figure 12: Emax dose-response with conc-dose ranges

if(!is.element("file:lib.modeling/.RData", search()))
	attach("lib.modeling/.RData")

x <- Emax.fit.and.plot(main="", sub="")$graphs$model.fit
graph2file(x, "12-dose.conc.response", width=c(480, 7), height=c(640, 7))

# ---
# Figure 13: biomarker graph

source("biomarker.graph.R")

x <- biomarker.graph()
graph2file(x, "13-biomarker", width=c(800, 8), height=c(500, 5))

# ---
# Figure 14: safety as Kaplan-Meier survival graphs

source("safety.as.survival.R")
x <- safety.as.survival()$graph
graph2file(x, "14-safety.as.survival", width=c(800, 8), height=c(500, 5))

# ---
# The End.

# rm(x)


