
change.from.baseline <- function(file="exdata1.csv", 
	ylab="Change from baseline")
{
	x <- read.csv(file, header=T)
	set.seed(43498)
	x$chg <- -1 * (x$hr - x$hr_bl) + rnorm(nrow(x), 0, 3)
	x$time <- x$time_ecg

	x <- x[, c("id", "time", "dgrp", "chg")]

	y <- x[is.element(x$dgrp, c(0, 10, 20)), ]
	y <- y[y$time < 12, ]
	y <- y[!is.na(y$chg), ]
	y <- y[order(y$id, y$time), ]

	# anonymize
	dg <- ifelse(y$dgrp==0, "Placebo", "Active")
	y$dgrp <- factor(dg)

	print(table(y$dgrp))

	y$time <- y$time * 2
	
	graphs <- list()

	require(lattice)

	pan <- function(x, y, ...)
	{
		# panel.abline(v=seq(0, 24, by=4), col="gray")
		panel.abline(v=pretty(x), col="gray")
		panel.abline(h=pretty(y), col="gray")

		panel.xyplot(x, y, ...)
		panel.abline(h=0, col="black", lwd=3)
	}

	graphs$default <- xyplot(chg ~ time, data=y, type="b", 
		ylab=ylab, groups=dgrp, panel=pan)

	graphs$centered <- xyplot(chg ~ time, 
		ylim=1.05 * c(-1, 1)*max(abs(y$chg)), 
		data=y, type="b", groups=dgrp, ylab=ylab, panel=pan)

	graphs$default.by.dgrp <- xyplot(chg ~ time | format(dgrp), 
		data=y, type="b", ylab=ylab, 
		layout=c(length(levels(y$dgrp)), 1),
		groups=dgrp)
		# Do NOT make it symmetric in y, no aux lines

	graphs$centered.by.dgrp <- xyplot(chg ~ time | format(dgrp), 
		layout=c(length(levels(y$dgrp)), 1),
		ylim=1.05 * c(-1, 1)*max(abs(y$chg)), 
		data=y, type="b", groups=dgrp, ylab=ylab, panel=pan)

	# Layout of two graphs for the book

	graphs[["combo"]] <- list(
		gr1=update(graphs$default.by.dgrp, 
			plot.args=list(position=c(0, 0, 0.5, 1.0), more=TRUE)
		),
		gr2=update(graphs$centered.by.dgrp, 
			plot.args=list(position=c(0.5, 0, 1.0, 1.0), more=FALSE)
		)
	)

	# ---
	# The End.

	return(graphs)
}

