# All combinations of values of a given data frame.
# Run combinations.all() without supplying any arguments and you see an
# example.
# Andreas Krause, Feb 2010

combinations.all <- function(
	x=list(numbers=1:5, uppercase=c("A", "B", "C"), lowercase=c("x", "y", "z"))
)
{
	U <- lapply(x, function(x) sort(unique(x)))
	n <- lapply(U, length)

	df <- data.frame(U[[1]])

	if(length(x) > 1)
		for(i in 2:length(x))
		{
			# repeat the existing data set rows as many times as there are
			# values in the next variable, and
			# repeat the values in the next variable as many times as there
			# are rows in the existing data, 
			# then put them into the data set that becomes the new data set

			n1 <- nrow(df)
			n2 <- n[[i]]

			x1 <- NULL
			for(j in 1:n2)
				x1 <- rbind(x1, df)

			x2 <- rep(U[[i]], rep(n1, n2))

			df <- cbind(x1, x2)	# the new base data set
		}

	names(df) <- names(x)

	# ---
	# Error checks

	# Number of rows must equal the product of the length of unique values

	if(nrow(df) != prod(unlist(n)))
		stop("Error in combinations: number of rows != product of lengths.")

	# Error check: each combination must occur exactly once
	# Multiply each colum with the number of unique values before that column
	# such that we get the numbers from 0 to (nrow-1)

	check <- lapply(df, function(x) as.numeric(as.factor(x)))
	factor <- c(1, cumprod(unlist(n)))

	for(i in 1:length(check))
		check[[i]] <- factor[i] * (check[[i]]-1)
	checksum <- rowSums(data.frame(check))

	if(any(duplicated(checksum)))
		stop("Checksum error in combinations: ",
			"duplicate checksum indicates error. See the code and the result.")

	# ---
	# The End.

	return(df)
}

