
# graph2file: write a (list of) lattice objects to graphics file(s)

graph2file <- function(
	graphs, 
	file="graph.tmp", 
	format=c("png", "wmf"), # "png", "wmf", etc.

	# height and width, vector lengths must correspond to length of format
	width=c(640, 7),
	height=c(640, 7),

	dir=setup$dir.graphs, 

	...
)
{
	# Loop over format vector (one file per format)
	for(i in 1:length(format))
	{
		# Determine function to use
		driver <- switch(format[i],
			"png"="png",
			"wmf"="win.metafile",
			stop("Cannot determine graphics driver for format ", this.format)
		)

		# Open the graphics file (e.g., graphs/boxplot.%03d.png)
		file.path <- paste(dir, "/", file, ".%03d.", format[i], sep="")
		cat("Writing to file(s) ", file.path, "... ")
		get(driver)(file=file.path, width=width[i], height=height[i], ...)
	
		print(x)	# print graph to output device

		# Close the graphics file
		dev.off()

		cat("done.\n")
	}

	return(invisible())
}

