
# Bars that show the number of records for the different values in x,
# optionally subset by the values observed in z.

# Example: EDA.freqchart(x=sample(c("m", "f"), 100, replace=TRUE),
#   z=sample(paste("dose", c(100, 200, 300)), 100, replace=TRUE))

EDA.freqchart <- function(x, z, ..., 
	layout=if(missing(z)) c(1, 1) else c(length(unique(z)), 1),
	xlab=if(missing(z)) deparse(substitute(x)) else
		paste(deparse(substitute(x)), "by", deparse(substitute(z))),
	ylab="n"
)
{

	require(lattice)

	if(missing(z))
		tbl <- t(t(table(x)))
	else
		tbl <- table(x, z) 

	ylim <- range(tbl)*1.05
	ylim[1] <- -0.05 * (max(ylim)-min(ylim))

	df <- data.frame(
		n=as.vector(tbl),
		x=rep(rownames(tbl), ncol(tbl))
	)

	if(!missing(z))
		df$z <- rep(colnames(tbl), rep(nrow(tbl), ncol(tbl)))

	require(lattice)

	formula <- "n ~ x"

	if(!missing(z))
		formula <- paste(formula, "| z")

	barchart(as.formula(formula), data=df, layout=layout, ..., 
		ylim=ylim, xlab=xlab, ylab=ylab)
}


