
# Hysteresis plot to explore delay between change in PK (concentration) and
# change in pharmacodynamics.
# Graph one profile of PD (y) versus PK(conc, x) per subject.


EDA.hysteresis <- function(
	# demo data set such that this function runs with default arguments
	data=data.frame(
		CONC=c(sort(runif(50)), rev(sort(runif(50)))), 
		HRdelta=runif(100, -1, 1), 
		ID=paste("ID", format(sample(1:10, 100, replace=TRUE)))
	),

	# variable names
	x="CONC",
	y="HRdelta",
	ID="ID",

	# lines (optional), set lines=NULL for no lines
	hline=0,
	vline=NULL,
	line.col="lightgray",

	# Lattice graphics parameters
	xlab=x,
	ylab=y,
	...  # e.g., type="b", scales=list(rel="free"), etc.
)
{
	# ---
	# Initialize

	require(lattice)

	# ---
	# Check for errors

if(FALSE)
	if(missing(data))
		stop("data not specified.")

	if(!is.data.frame(data))
		data <- as.data.frame(data)

	check <- c("x", "y", "ID")

	for(what in check)
		if(!is.element(get(what), names(data)))
			stop(what, "=\"", get(what), "\" not found in data set.")

	# ---
	# The graph

	graph <- xyplot(data[[y]] ~ data[[x]] | format(data[[ID]]),
		as.table=TRUE,
		xlab=xlab,
		ylab=ylab,

		...,
		panel=function(x, y, ..., subscripts, D)
		{
			# auxiliary lines first
			if(length(hline) > 0)
				panel.abline(h=hline, col=line.col)

			if(length(vline) > 0)
				panel.abline(v=vline, col=line.col)

			# the profile
			panel.arrows(x[-length(x)], y[-length(y)], x[-1], y[-1], 
				type="closed", fill="darkred", length=0.075, ...)
		}
	)

	return(graph)

}

