
# ---
# Inverse of the Emax function (note the y argument)
# Application: Derive particular (x, y) values of interest, 
# for example the x where y=80% Emax

Emax.inv <- function(E0=0, EC50, Emax, gamma=1, y)
{
	if(missing(E0) | is.na(E0)) E0 <- 0
	if(missing(gamma) | is.na(gamma)) gamma <- 1

	if(missing(EC50) | is.na(EC50)) stop("EC50 missing")
	if(missing(Emax) | is.na(Emax)) stop("Emax missing")

	# Handle 0% and 100% effect
	OK1 <- (y > E0) & (y < E0+Emax)	# Emax > 0
	OK2 <- (y < E0) & (y > E0+Emax)	# Emax < 0
	OK  <- OK1 | OK2

	x1 <- (y-E0)/Emax
	x2 <- rep(NA, length(x1))
	x2[OK] <- log(EC50) - log(1/x1[OK] -1)/gamma

	# Boundaries
	x2[y==E0] <- -Inf
	x2[y==(E0+Emax)] <- +Inf

	result <- exp(x2)

	return(result)
}

