
# Determine default x-axis tickmarks and labels for the Emax function.

Emax.xaxis.at <- function(x, logscale, xlim=range(x, na.rm=TRUE))
{
	xmin <- min(x, na.rm=T)
	xmax <- max(x, na.rm=T)

	if(logscale)
	{
		# use only integers of power of 10.
		# Determine range of data, expand gently to left and right,
		# and return the sequence of powers of 10 on that range.

		# Use 5 and 10*10^(-10:10)
		r1 <- (-10:10)	# data are on log scale already
		r2 <- log10(5)+seq(0, 10, by=1)
		r3 <- log10(1/5)-seq(0, 10, by=1)
		r <- sort(c(r1, r2, r3))

		if(missing(xlim))
			idx <- which(r >= xmin & r <= xmax)
		else
			idx <- which(r >= min(xlim) & r <= max(xlim))

		idx <- range(idx)
		if(length(idx) < 2) idx <- rep(idx, 2) # for narrow ranges

		if(idx[1] > 1) idx[1] <- idx[1]-1
		if(idx[2] < length(r)) idx[2] <- idx[2]+1

		idx <- seq(idx[1], idx[2], by=1)

		r <- r[idx]	# take out the r values in the range of the data

		# If the data span a larger range than r, add the data min/max
		if(xmin < min(r)) r <- c(xmin, r)
		if(xmax > max(r)) r <- c(r, xmax)

		r	# return x-axis limits

	}
	else 
		r <- pretty(x, n=12)
	
	return(r)

}


