# Compare two variables, x and y.
# The graph is square, ranges are identical.
# Options:
# - add the line of identity
# - use a conditioning variable, z

modeling.compare.xy <- function(
	x, y, 	# must be character (variable names in data!)
	z, z2,	# optional conditioning variables
	data=data,
	show.diagonal=TRUE,

	add.lmline=FALSE, lmline.col="darkblue", lmline.lwd=2,
	add.loess =FALSE,  loess.col="darkred",  loess.lwd=2,

	add.grid=TRUE,	# auxiliary lines in the graph
	...
)
{
	if(missing(data))
		stop("data not specified.")

	if(!is.data.frame(data))
		data <- data.frame(data)

	if(!is.element(x, names(data)))
		stop("x=\"", x, "\" seems wrong. No such variable.")

	if(!is.element(y, names(data)))
		stop("y=\"", y, "\" seems wrong. No such variable.")

	if(!missing(z) && !is.element(z, names(data)))
		stop("z=\"", z, "\" seems wrong. No such variable.")

	if(!missing(z2) && !is.element(z2, names(data)))
		stop("z2=\"", z2, "\" seems wrong. No such variable.")

	lims <- range(c(data[[x]], data[[y]]), na.rm=TRUE)
	lims <- range(c(data[[x]], data[[y]]), na.rm=TRUE)
	lims.delta <- lims[2]-lims[1]
	lims <- lims + c(-1, 1) * 0.02 * lims.delta

	f <- paste(y, "~",  x)
	if(!missing(z))
		f <- paste(f, "| format(",  z, ")", sep="")

	if(!missing(z2))
		f <- paste(f, "*",  z2, sep="")

	require(lattice)

	xyplot(as.formula(f), data=data, 
		xlim=lims, ylim=lims,
		aspect=1, 
		panel=function(x, y, ...)
		{
			if(add.grid)
				panel.grid(h=-1, v=-1)

			panel.xyplot(x, y, ...)

			if(show.diagonal)
				panel.abline(0, 1, col="black")

			if(add.lmline)
				panel.lmline(x, y, ..., col=lmline.col, lwd=lmline.lwd)

			if(add.loess)
				panel.loess (x, y, ..., col=loess.col,  lwd=loess.lwd)
		},
		...
	)
}

