
# Enhance the summary function for a model fit by further columns.
# %CV

summary.extended <- function(
	fit,	#  a model fit, for example from lm, glm, nls
	classes.allowed=c("nls", "lm", "glm")	# tested for these classes
)
{

	OK <- any(is.element(class(fit), classes.allowed))
	if(!OK)
		warning("Class(es) ", paste(class(fit), collapse=", "), " not tested.")

	fit.summary <- summary(fit)

	coeff <- coefficients(fit.summary)
	if(!is.matrix(coeff))
		stop("$coefficients component is not a matrix: something went wrong!")

	# add column %CV
	coeff <- cbind(coeff, 
		"%CV"=100*coeff[, "Std. Error"]/abs(coeff[, "Estimate"])
	)

	fit.summary$coefficients <- coeff

	return(fit.summary)
}

