# Compare predicatd and observed.
# Example.

obspred <- function(n=300)
{
	set.seed(98798)

	observed  <- rnorm(n, m=50, s=5)
	predicted <- observed + rnorm(n, 0, s=5)

	require(lattice)

	panel.compare <- function(x, y, ...)
	{
		panel.abline(0, 1, col="gray")
		panel.xyplot(x, y, ...)
	}

	graphs <- list()

	graphs[["obs ~ pred"]] <- xyplot(
		observed ~ predicted,
		panel=panel.compare
	)

	graphs[["pred ~ obs"]] <- xyplot(
		predicted ~ observed,
		panel=panel.compare
	)

	R <- range(c(predicted, observed))
	R <- R + c(-1, 1) * 0.05 * (R[2]-R[1])

	graphs[["perfect"]] <- xyplot(
		predicted ~ observed,
		xlim=R, ylim=R,
		aspect=1,
		panel=panel.compare
	)

	# Combination of graphs
	# Some extra white space left (top/bottom on the left) to have
	# a more "dramatic" effect of aspect ratio

	graphs[["combo"]] <- list(
		# top left figure
		gr1=update(graphs[["obs ~ pred"]],
			plot.args=list(position=c(0.0, 0.45, 0.5, 0.95), more=TRUE)),
		# bottom left figure
		gr2=update(graphs[["pred ~ obs"]],
			plot.args=list(position=c(0.0, 0.05, 0.5, 0.55), more=TRUE)),
		# rhs figure
		gr3=update(graphs[["perfect"]],
			plot.args=list(position=c(0.5, 0.0, 1.0, 1.0), more=FALSE))
	)


	# ---
	# The End.

	return(graphs)
}

