
outliers <- function(
	n=100,
	x=c(70, rnorm(n-1, 40, 3)),
	y=c(rnorm(0.97*n, 100-x/10, 1.5), rnorm(0.03*n, 95-x/10, 1)),
	y.outliers=c(0.7) * mean(y)
	# y.outliers=c(0.7, 1.3) * mean(y)
)
{
	require(lattice)
	set.seed(949382)

	graphs <- list()

	graphs[["low"]] <- xyplot(y ~ x, 
		xlab="age", ylab="drug effect",
		ylim=range(c(y, y.outliers)) + c(-5, 5),
		y.outliers=y.outliers,
		panel=function(x, y, ..., y.outliers)
		{
			n <- length(x)
			y.new <- y

			for(i in 1:length(y.outliers))
			{	
				y.new[1] <- y.outliers[i]

				panel.xyplot(x, y.new, ...)
				panel.xyplot(x[1], y.new[1], ..., pch=16, col="darkred")
				panel.lmline(x, y.new, ..., col="darkred", lwd=2)
				panel.lmline(x[-1], y.new[-1], ..., col="darkred", lwd=1, lty=3)

				panel.loess(x, y.new, ..., col="darkgreen", lwd=2, lty=2)
			}
		}
	)

	# No 2

	graphs[["omit"]] <- xyplot(y ~ x, 
		xlab="age", ylab="drug effect",
		xlim=range(x[-1]) + 1*c(-1, 1),
		ylim=range(y[-1]) + 1*c(-1, 1),
		y.outliers=y.outliers,
		panel=function(x, y, ..., y.outliers)
		{
			n <- length(x)
			panel.xyplot(x, y, ...)
			panel.lmline(x, y, ..., col="darkred", lwd=2, lty=1)
			panel.loess(x, y, ..., col="darkgreen", lwd=2, lty=2)

			# ---
			# indicate the outlier

			out.str.x <- as.character(round(x[1]))
			out.str.y <- as.character(round(y.outliers[1]))
			x[1] <- max(x[-1])
			y[1] <- min(y[-1])
			panel.text(x[1], y[1],
				paste("\n(", out.str.x, ",", out.str.y, ")    ", sep=""), 
				adj=0.5)
			panel.points(x[1], y[1], pch=16, col="red")

		}
	)

	# Combo of graphs

	graphs[["combo"]] <- list(
		gr1=update(graphs$low , 
			plot.args=list(position=c(0.0, 0, 0.5, 1.0), more=TRUE)),
		gr2=update(graphs$omit, 
			plot.args=list(position=c(0.5, 0, 1.0, 1.0), more=FALSE))
	)

	# ---
	# The End.

	return(graphs)
}

